==> azure_mgmt_costmanagement-0.2.0.crate: azure_mgmt_costmanagement-0.2.0/README.md <==
# azure_mgmt_costmanagement crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/cost-management/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-10`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2022-02` has 3 operations from 1 API versions: `2022-02-01-preview`. Use crate feature `package-preview-2022-02` to enable. The operations will be in the `package_preview_2022_02` module.
- `package-2021-10` has 30 operations from 1 API versions: `2021-10-01`. Use crate feature `package-2021-10` to enable. The operations will be in the `package_2021_10` module.
- `package-2021-01` has 28 operations from 2 API versions: `2020-06-01`, `2021-01-01`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.
- `package-preview-2020-12` has 28 operations from 2 API versions: `2020-06-01`, `2020-12-01-preview`. Use crate feature `package-preview-2020-12` to enable. The operations will be in the `package_preview_2020_12` module.
- `package-preview-2020-03` has 24 operations from 2 API versions: `2020-03-01-preview`, `2020-06-01`. Use crate feature `package-preview-2020-03` to enable. The operations will be in the `package_preview_2020_03` module.
- `package-2020-06` has 25 operations from 1 API versions: `2020-06-01`. Use crate feature `package-2020-06` to enable. The operations will be in the `package_2020_06` module.
- `package-2019-11` has 31 operations from 1 API versions: `2019-11-01`. Use crate feature `package-2019-11` to enable. The operations will be in the `package_2019_11` module.
- `package-2019-10` has 9 operations from 1 API versions: `2019-10-01`. Use crate feature `package-2019-10` to enable. The operations will be in the `package_2019_10` module.
- `package-2019-09` has 9 operations from 1 API versions: `2019-09-01`. Use crate feature `package-2019-09` to enable. The operations will be in the `package_2019_09` module.
- `package-preview-2019-04` has 13 operations from 1 API versions: `2019-04-01-preview`. Use crate feature `package-preview-2019-04` to enable. The operations will be in the `package_preview_2019_04` module.
- `package-2019-01` has 9 operations from 1 API versions: `2019-01-01`. Use crate feature `package-2019-01` to enable. The operations will be in the `package_2019_01` module.
- `package-preview-2019-03` has 36 operations from 1 API versions: `2019-03-01-preview`. Use crate feature `package-preview-2019-03` to enable. The operations will be in the `package_preview_2019_03` module.
- `package-2018-05` has 15 operations from 1 API versions: `2018-05-31`. Use crate feature `package-2018-05` to enable. The operations will be in the `package_2018_05` module.

==> azure_mgmt_costmanagement-0.3.0.crate: azure_mgmt_costmanagement-0.3.0/README.md <==
# azure_mgmt_costmanagement crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/cost-management/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-2021-10`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2022-02` has 3 operations from 1 API versions: `2022-02-01-preview`. Use crate feature `package-preview-2022-02` to enable. The operations will be in the `package_preview_2022_02` module.
- `package-preview-2022-04` has 39 operations from 2 API versions: `2021-10-01`, `2022-04-01-preview`. Use crate feature `package-preview-2022-04` to enable. The operations will be in the `package_preview_2022_04` module.
- `package-2021-10` has 30 operations from 1 API versions: `2021-10-01`. Use crate feature `package-2021-10` to enable. The operations will be in the `package_2021_10` module.
- `package-2021-01` has 28 operations from 2 API versions: `2020-06-01`, `2021-01-01`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.
- `package-preview-2020-12` has 28 operations from 2 API versions: `2020-06-01`, `2020-12-01-preview`. Use crate feature `package-preview-2020-12` to enable. The operations will be in the `package_preview_2020_12` module.
- `package-preview-2020-03` has 24 operations from 2 API versions: `2020-03-01-preview`, `2020-06-01`. Use crate feature `package-preview-2020-03` to enable. The operations will be in the `package_preview_2020_03` module.
- `package-2020-06` has 25 operations from 1 API versions: `2020-06-01`. Use crate feature `package-2020-06` to enable. The operations will be in the `package_2020_06` module.
- `package-2019-11` has 31 operations from 1 API versions: `2019-11-01`. Use crate feature `package-2019-11` to enable. The operations will be in the `package_2019_11` module.
- `package-2019-10` has 9 operations from 1 API versions: `2019-10-01`. Use crate feature `package-2019-10` to enable. The operations will be in the `package_2019_10` module.
- `package-2019-09` has 9 operations from 1 API versions: `2019-09-01`. Use crate feature `package-2019-09` to enable. The operations will be in the `package_2019_09` module.
- `package-preview-2019-04` has 13 operations from 1 API versions: `2019-04-01-preview`. Use crate feature `package-preview-2019-04` to enable. The operations will be in the `package_preview_2019_04` module.
- `package-2019-01` has 9 operations from 1 API versions: `2019-01-01`. Use crate feature `package-2019-01` to enable. The operations will be in the `package_2019_01` module.
- `package-preview-2019-03` has 36 operations from 1 API versions: `2019-03-01-preview`. Use crate feature `package-preview-2019-03` to enable. The operations will be in the `package_preview_2019_03` module.
- `package-2018-05` has 15 operations from 1 API versions: `2018-05-31`. Use crate feature `package-2018-05` to enable. The operations will be in the `package_2018_05` module.
